import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { TestResultVO, TestResultForm, TestResultQuery } from '@/api/qms/testResult/types';

/**
 * 查询测试结果列表
 * @param query
 * @returns {*}
 */

export const listTestResult = (query?: TestResultQuery): AxiosPromise<TestResultVO[]> => {
  return request({
    url: '/qms/testResult/list',
    method: 'get',
    params: query
  });
};


/**
 * 查询测试结果列表
 * @param query
 * @returns {*}
 */

export const listTestResultAll = (query?: TestResultQuery): AxiosPromise<TestResultVO[]> => {
  return request({
    url: '/qms/testResult/listAll',
    method: 'get',
    params: query
  });
};
/**
 * 查询测试项目
 * @param query
 * @returns {*}
 */
export const listTestItem = () => {
  return request({
    url: '/qms/testResult/distinctTestItems',
    method: 'get'
  });
};

/**
 * 查询测试结果详细
 * @param id
 */
export const getTestResult = (id: string | number): AxiosPromise<TestResultVO> => {
  return request({
    url: '/qms/testResult/' + id,
    method: 'get'
  });
};

/**
 * 新增测试结果
 * @param data
 */
export const addTestResult = (data: TestResultForm) => {
  return request({
    url: '/qms/testResult',
    method: 'post',
    data: data
  });
};

/**
 * 修改测试结果
 * @param data
 */
export const updateTestResult = (data: TestResultForm) => {
  return request({
    url: '/qms/testResult',
    method: 'put',
    data: data
  });
};

/**
 * 删除测试结果
 * @param id
 */
export const delTestResult = (id: string | number | Array<string | number>) => {
  return request({
    url: '/qms/testResult/' + id,
    method: 'delete'
  });
};
